package com.hikcreate.edl.pub.web.mobile.api.controller;

import com.hikcreate.edl.pub.web.mobile.domain.IBindService;
import com.hikcreate.edl.pub.web.mobile.infra.core.Result;
import com.hikcreate.edl.pub.web.mobile.infra.core.enums.ResultCode;
import com.hikcreate.edl.pub.web.mobile.infra.model.BindInfoQuery;
import com.hikcreate.edl.pub.web.mobile.infra.model.param.response.DrivingLicenseInfoRes;
import com.hikcreate.edl.pub.web.mobile.infra.model.param.response.InsuranceInfoRes;
import com.hikcreate.edl.pub.web.mobile.infra.model.param.response.ViolationInfoRes;
import com.hikcreate.edl.pub.web.mobile.infra.model.param.response.YearCheckInfoRes;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 对外提供给H5的接口
 *
 * @author: xieshixiang
 * @time：2020/6/19 16:37
 **/
@RestController
@RequestMapping("/vehicle")
@Slf4j
public class H5Controller {

    @Autowired
    IBindService service;
    /**
     * 年检信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 10:32
     */
    @PostMapping("yearCheckInfo")
    public Result<YearCheckInfoRes> yearCheckInfo(@RequestBody BindInfoQuery query) {
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "鉴权失败");
        }
        return service.yearCheckInfo(query);
    }

    /**
     * 违法信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 16:28
     */
    @PostMapping("violationInfo")
    public Result<ViolationInfoRes> violationInfo(@RequestBody BindInfoQuery query) {
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "鉴权失败");
        }
        return service.violationInfo(query);
    }
    /**
     * 保险信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 16:28
     */
    @PostMapping("insuranceInfo")
    public Result<InsuranceInfoRes> insuranceInfo(@RequestBody BindInfoQuery query){
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "鉴权失败");
        }
        return service.insuranceInfo(query);
    }

    /**
     * 驾照信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 16:28
     */
    @PostMapping("drivingLicenseInfo")
    public Result<DrivingLicenseInfoRes> drivingLicenseInfo(@RequestBody BindInfoQuery query) {
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "鉴权失败");
        }
        return service.drivingLicenseInfo(query);
    }
}
